get_defillama_chain_hist_tvl: Chain History Data

View source: R/get_defillama_chain_hist_tvl.R

get_defillama_chain_hist_tvlR Documentation

Chain History Data

Description

Fetches historical TVL data for a specified Blockchain in USD. The data is returned as a table sorted by date.

Usage

get_defillama_chain_hist_tvl(name)

Arguments

name

A string representing the unique name (name) of the protocol. This name can be obtained from the result of the get_defillama_chain_tvl function.

Value

A 'data.table' object containing historical TVL data of the specified chain The table includes columns for date, TVL in USD. It is sorted by date.

Examples

# total tvl by date
chain_tvl = get_defillama_chain_hist_tvl( "Ethereum" )
tail( chain_tvl )

rllama documentation built on May 29, 2024, 4:40 a.m.