Learn R Programming

rllama (version 0.4.4)

get_defillama_stablecoin_data: Stablecoins Data

Description

Retrieves stablecoin data, including details like name, symbol, price, and market cap. The data is returned as a sorted table by market cap.

Usage

get_defillama_stablecoin_data()

Arguments

Value

A `data.table` with stablecoin information, sorted by market capitalization.

Examples

Run this code
stablecoin_data = get_defillama_stablecoin_data()
head( stablecoin_data )

Run the code above in your browser using DataLab