Learn R Programming

rllama (version 0.4.4)

get_defillama_stablecoin_hist_data: Stablecoins History Data

Description

Retrieves stablecoin data, including details like name, symbol, price, and market cap. The data is returned as a sorted table.

Usage

get_defillama_stablecoin_hist_data(stablecoin_id)

Value

A `data.table` object containing historical data of the specified stablecoin. The table is sorted by date.

Arguments

stablecoin_id

An integer representing the ID of the stablecoin. This ID can be obtained from the result of the get_defillama_stablecoin_data function.

Examples

Run this code
# \donttest{
stablecoin_hist_data = get_defillama_stablecoin_hist_data( 5 )
head( stablecoin_hist_data )
# }

Run the code above in your browser using DataLab