View source: R/get_defillama_chain_hist_tvl.R
| get_defillama_chain_hist_tvl | R Documentation |
Fetches historical TVL data for a specified Blockchain in USD. The data is returned as a table sorted by date.
get_defillama_chain_hist_tvl(name)
name |
A string representing the unique name (name) of the protocol.
This name can be obtained from the result of the |
A 'data.table' object containing historical TVL data of the specified chain The table includes columns for date, TVL in USD. It is sorted by date.
# total tvl by date
chain_tvl = get_defillama_chain_hist_tvl( "Ethereum" )
tail( chain_tvl )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.