powered by
Fetches historical TVL data for a specified Blockchain in USD. The data is returned as a table sorted by date.
get_defillama_chain_hist_tvl(name)
A `data.table` object containing historical TVL data of the specified chain The table includes columns for date, TVL in USD. It is sorted by date.
A string representing the unique name (name) of the protocol. This name can be obtained from the result of the get_defillama_chain_tvl function.
get_defillama_chain_tvl
# total tvl by date chain_tvl = get_defillama_chain_hist_tvl( "Ethereum" ) tail( chain_tvl )
Run the code above in your browser using DataLab