powered by
Retrieves stablecoin data, including details like name, symbol, price, and market cap. The data is returned as a sorted table by market cap.
get_defillama_stablecoin_data()
A `data.table` with stablecoin information, sorted by market capitalization.
stablecoin_data = get_defillama_stablecoin_data() head( stablecoin_data )
Run the code above in your browser using DataLab