powered by
Retrieves stablecoin data, including details like name, symbol, price, and market cap. The data is returned as a sorted table.
get_defillama_stablecoin_hist_data(stablecoin_id)
A `data.table` object containing historical data of the specified stablecoin. The table is sorted by date.
An integer representing the ID of the stablecoin. This ID can be obtained from the result of the get_defillama_stablecoin_data function.
get_defillama_stablecoin_data
# \donttest{ stablecoin_hist_data = get_defillama_stablecoin_hist_data( 5 ) head( stablecoin_hist_data ) # }
Run the code above in your browser using DataLab